@@ -8,20 +8,22 @@ from getpass import getpass
 from subprocess import Popen
 
 import peewee
-
 import argh
 from argh.decorators import aliases, arg
+
 from tmc import api
 from tmc.errors import (APIError, NoCourseSelected, NoExerciseSelected,
                         TMCError, TMCExit)
 from tmc.exercise_tests.basetest import run_test
 from tmc.files import download_exercise, submit_exercise
 from tmc.models import Config, Course, Exercise, reset_db
+from tmc.coloring import infomsg
 from tmc.ui.menu import Menu
 from tmc.ui.prompt import custom_prompt, yn_prompt
 from tmc.ui.spinner import Spinner
 from tmc.version import __version__
 
+
 try:
     from subprocess import DEVNULL
 except ImportError:
@@ -68,6 +70,26 @@ def false_exit(func):
     return inner
 
 
+def check_for_updates():
+    from xmlrpc.client import ServerProxy
+    from distutils.version import StrictVersion
+    pypi = ServerProxy("http://pypi.python.org/pypi")
+    version = StrictVersion(__version__)
+    pypiversion = StrictVersion(pypi.package_releases("tmc")[0])
+    if pypiversion > version:
+        infomsg("There is a new version available. ({})".format(pypiversion))
+        print("You can upgrade tmc.py with either of these ways, depending",
+              "on the way you installed tmc.py in the first place.",
+              "\nIf you installed it with pip:",
+              "\n    sudo pip install --upgrade tmc",
+              "\nIf you installed it with the installation script:",
+              "\n    Run the script again and select upgrade.")
+    elif pypiversion < version:
+        print("You are running a newer version than available.")
+    else:
+        print("You are running the most current version.")
+
+
 @aliases("init", "conf")
 @arg("-s", "--server", help="Server address to be used.")
 @arg("-u", "--username", help="Username to be used.")
@@ -81,8 +103,7 @@ def configure(server=None, username=None, password=None, tid=None, auto=False):
     """
     if not server and not username and not password and not tid:
         if Config.has():
-            sure = input("Override old configuration [y/N]: ")
-            if sure.upper() != "Y":
+            if not yn_prompt("Override old configuration", False):
                 return False
     reset_db()
     if not server:
@@ -361,9 +382,8 @@ def update(course=False):
     Update the metadata of courses and or exercises from server.
     """
     if course:
-        @Spinner.decorate("Updated course metadata.",
-                          waitmsg="Updating course metadata.")
-        def update_course():
+        with Spinner.context(msg="Updated course metadata.",
+                             waitmsg="Updating course metadata."):
             for course in api.get_courses():
                 old = None
                 try:
@@ -372,15 +392,12 @@ def update(course=False):
                     old = None
                 if old:
                     continue
-                Course.create(tid=course["id"],
-                              name=course["name"])
-        update_course()
+                Course.create(tid=course["id"], name=course["name"])
     else:
         selected = Course.get_selected()
 
-        @Spinner.decorate("Updated exercise metadata.",
-                          waitmsg="Updating exercise metadata.")
-        def update_exercise():
+        with Spinner.context(msg="Updated exercise metadata.",
+                             waitmsg="Updating exercise metadata."):
             for exercise in api.get_exercises(selected.tid):
                 old = None
                 try:
@@ -404,7 +421,6 @@ def update(course=False):
                                          deadline=exercise.get("deadline"))
                     ex.is_downloaded = os.path.isdir(ex.path())
                     ex.save()
-        update_exercise()
 
 
 @selected_course
@@ -445,13 +461,68 @@ def version():
     print("tmc.py version {0}".format(__version__))
     print("Copyright 2014 tmc.py contributors")
 
+
+def should_update():
+    from xmlrpc.client import ServerProxy
+    from distutils.version import StrictVersion
+    from datetime import datetime
+    import calendar
+
+    current_version = StrictVersion(__version__)
+    last_value = Config.has_name("needs_update") \
+        and Config.get_value("needs_update") == "1"
+    last_version = (0,0,0)
+    if Config.has_name("last_version"):
+        last_version = StrictVersion(Config.get_value("last_version"))
+
+    # Return false if an upgrade has happened
+    if last_value and (last_version < current_version):
+        return False
+
+    Config.set("last_version", __version__)
+
+    # Next lets check the time
+    last_time = None
+    if Config.has_name("last_update_check"):
+        last_time = datetime.utcfromtimestamp(int(
+            Config.get_value("last_update_check")))
+    else:
+        last_time = datetime.now()
+
+    if (last_time - datetime.now()).days < 7:
+        return False
+
+    Config.set("last_update_check",
+               calendar.timegm(datetime.now().timetuple()))
+
+    # Lastly lets check pypi for versions
+    pypi = ServerProxy("http://pypi.python.org/pypi")
+    pypiversion = StrictVersion(pypi.package_releases("tmc")[0])
+
+    if pypiversion > current_version:
+        return True
+    return False
+
+
 commands = [select, update, download, test, submit, skip, current, previous,
-            reset, configure, version, list_all, run]
+            reset, configure, version, list_all, run, check_for_updates]
 
 
 def main():
     parser = argh.ArghParser()
     parser.add_commands(commands)
+
+    needs_update = should_update()
+    Config.set("needs_update", "1" if needs_update else "0")
+    if needs_update:
+        infomsg("Update available to tmc.py. See tmc check-for-updates",
+                "for more info.")
+
+    # By default Argh only shows shortened help when no command is given.
+    # This makes it print out the full help instead.
+    if len(sys.argv) == 1:
+        return parser.dispatch(argv=["help"])
+
     try:
         parser.dispatch()
     except TMCError as e:
