@@ -3,10 +3,9 @@ import time
 import zipfile
 from io import BytesIO
 
-from tmc import api
+from tmc import api, conf
 from tmc.errors import NotDownloaded, TMCError, WrongExerciseType
 from tmc.ui.spinner import Spinner
-
 from tmc.coloring import successmsg, warningmsg, errormsg, infomsg
 
 
@@ -26,15 +25,13 @@ def download_exercise(exercise, force=False, update_java=False):
                 pass
         return
 
-    @Spinner.decorate("Downloaded.", waitmsg="Downloading.")
-    def inner(exercise):
+    with Spinner.context(msg="Downloaded.", waitmsg="Downloading."):
         tmpfile = BytesIO()
         api.get_zip_stream(exercise.tid, tmpfile)
         zipfp = zipfile.ZipFile(tmpfile)
         zipfp.extractall(outpath)
         exercise.is_downloaded = True
         exercise.save()
-    inner(exercise)
 
     if update_java:
         try:
@@ -74,9 +71,10 @@ def submit_exercise(exercise, request_review=False, pastebin=False):
     if pastebin:
         params["paste"] = "wolololo"
 
-    @Spinner.decorate("Submission has been sent.",
-                      waitmsg="Sending submission.")
-    def inner():
+    resp = None
+
+    with Spinner.context(msg="Submission has been sent.",
+                         waitmsg="Sending submission."):
         tmpfile = BytesIO()
         zipfp = zipfile.ZipFile(tmpfile, "w")
         for root, _, files in os.walk(outpath):
@@ -86,8 +84,7 @@ def submit_exercise(exercise, request_review=False, pastebin=False):
                                             os.path.join(outpath, '..')),
                             zipfile.ZIP_DEFLATED)
         zipfp.close()
-        return api.send_zip(exercise.tid, tmpfile.getvalue(), params)
-    resp = inner()
+        resp = api.send_zip(exercise.tid, tmpfile.getvalue(), params)
 
     if "submission_url" not in resp:
         return
@@ -95,7 +92,7 @@ def submit_exercise(exercise, request_review=False, pastebin=False):
     url = resp["submission_url"]
     submission_id = int(url.split(".json")[0].split("submissions/")[1])
 
-    @Spinner.decorate("Results:", "Waiting for results.")
+    @Spinner.decorate(msg="Results:", waitmsg="Waiting for results.")
     def inner():
         while True:
             data = api.get_submission(submission_id)
@@ -113,7 +110,8 @@ def submit_exercise(exercise, request_review=False, pastebin=False):
         warningmsg("------------------")
         for test in data["test_cases"]:
             if test["successful"]:
-                successmsg("{name}: {message}\n".format(**test))
+                if conf.show_successful_tests():
+                    successmsg("{name}: {message}".format(**test))
             else:
                 errormsg("{name}:\n  {message}".format(**test))
 
@@ -126,6 +124,8 @@ def submit_exercise(exercise, request_review=False, pastebin=False):
         successmsg("---------------------")
         points = ", ".join(data["points"])
         successmsg("Points [{0}]".format(points))
+        exercise.is_completed = exercise.is_attempted = True
+        exercise.save()
 
     elif status == "error":
         warningmsg("Something went wrong :(")
